@@ -81,7 +81,7 @@ typedef enum MSFilterId{
 	MS_H263_OLD_ENC_ID,
 	MS_MIRE_ID,
 	MS_VFW_ID,
-	MS_ICE_ID,
+	MS_VOID_SOURCE_ID,
 	MS_VOID_SINK_ID,
 	MS_DSCAP_ID,
 	MS_AQ_READ_ID,
@@ -91,7 +91,57 @@ typedef enum MSFilterId{
 	MS_JPEG_ENC_ID,
 	MS_PULSE_READ_ID,
 	MS_PULSE_WRITE_ID,
-	MS_DRAWDIB_DISPLAY_ID
+	MS_DRAWDIB_DISPLAY_ID,
+	MS_CHANNEL_ADAPTER_ID,
+	MS_AUDIO_MIXER_ID,
+	MS_ITC_SINK_ID,
+	MS_ITC_SOURCE_ID,
+	MS_EXT_DISPLAY_ID,
+	MS_H264_DEC_ID,
+	MS_IOUNIT_READ_ID,
+	MS_IOUNIT_WRITE_ID,
+	MS_ANDROID_SOUND_READ_ID,
+	MS_ANDROID_SOUND_WRITE_ID,
+	MS_JPEG_WRITER_ID,
+	MS_X11VIDEO_ID,
+	MS_ANDROID_DISPLAY_ID,
+	MS_ANDROID_VIDEO_READ_ID,
+	MS_ANDROID_VIDEO_WRITE_ID,
+	MS_TONE_DETECTOR_ID,
+    MY_FILTER_ID,
+	MS_IOS_DISPLAY_ID,
+	MS_VP8_ENC_ID,
+	MS_VP8_DEC_ID,
+	MS_G722_ENC_ID,
+	MS_G722_DEC_ID,
+	MS_G726_40_ENC_ID,
+	MS_G726_32_ENC_ID,
+	MS_G726_24_ENC_ID,
+	MS_G726_16_ENC_ID,
+	MS_AAL2_G726_40_ENC_ID,
+	MS_AAL2_G726_32_ENC_ID,
+	MS_AAL2_G726_24_ENC_ID,
+	MS_AAL2_G726_16_ENC_ID,
+	MS_G726_40_DEC_ID,
+	MS_G726_32_DEC_ID,
+	MS_G726_24_DEC_ID,
+	MS_G726_16_DEC_ID,
+	MS_AAL2_G726_40_DEC_ID,
+	MS_AAL2_G726_32_DEC_ID,
+	MS_AAL2_G726_24_DEC_ID,
+	MS_AAL2_G726_16_DEC_ID,
+	MS_L16_ENC_ID,
+	MS_L16_DEC_ID,
+	MS_OSX_GL_DISPLAY_ID,
+	MS_GLXVIDEO_ID,
+	MS_GENERIC_PLC_ID,
+	MS_WEBRTC_AEC_ID,
+	MS_AAC_ELD_ENC_ID,
+	MS_AAC_ELD_DEC_ID,
+	MS_OPUS_ENC_ID,
+	MS_OPUS_DEC_ID,
+	MS_QSA_READ_ID,
+	MS_QSA_WRITE_ID
 } MSFilterId;
 
 
